@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 
-$CPAN::Reporter::VERSION = '0.99_02'; 
+$CPAN::Reporter::VERSION = '0.99_05'; 
 
 use Config;
 use Config::Tiny ();
@@ -176,7 +176,7 @@ sub grade_test {
     _compute_test_grade($result);
     if ( $result->{grade} eq 'discard' ) {
         $CPAN::Frontend->mywarn( 
-            "\nTest results were not valid: $result->{grade_msg}\n\n",
+            "\nCPAN::Reporter: Test results were not valid, $result->{grade_msg}\n\n",
             $result->{prereq_pm}, "\n",
             "Test results for $result->{dist_name} will be discarded"
         );
@@ -875,8 +875,8 @@ sub _prereq_report {
 sub _print_grade_msg {
     my ($phase, $result) = @_;
     my ($grade, $msg) = ($result->{grade}, $result->{grade_msg});
-    $CPAN::Frontend->myprint( "$phase result is '$grade'");
-    $CPAN::Frontend->myprint(": $msg") if defined $msg && length $msg;
+    $CPAN::Frontend->myprint( "CPAN::Reporter: $phase result is '$grade'");
+    $CPAN::Frontend->myprint(", $msg") if defined $msg && length $msg;
     $CPAN::Frontend->myprint(".\n");
     return;
 }
@@ -1345,10 +1345,10 @@ From the CPAN shell:
 
 = DESCRIPTION
 
-CPAN::Reporter is an add-on for the CPAN.pm module that uses
-[Test::Reporter] to send the results of module tests to the CPAN
-Testers project.  Support for CPAN::Reporter is available in CPAN.pm 
-as of version 1.88.
+CPAN::Reporter is an add-on for the CPAN.pm module that uses [Test::Reporter]
+to send the results of module tests to the CPAN Testers project.  Partial
+support for CPAN::Reporter is available in CPAN.pm as of version 1.88; full
+support is available in CPAN.pm as of version 1.91_53.
 
 The goal of the CPAN Testers project ([http://testers.cpan.org/]) is to
 test as many CPAN packages as possible on as many platforms as
