@@ -110,7 +110,7 @@ sub test_grade_PL {
                                             : "$perl Build.PL";
 
             eval "require $tool_mod";
-            skip "$tool_mod not installed", test_grade_iter_plan()
+            skip "$tool_mod not installed", test_grade_PL_iter_plan()
                 if $@;
             
             my $pushd = pushd( _ok_clone_dist_dir( $case->{name} ) );
@@ -141,7 +141,7 @@ sub test_grade_PL {
 
             # correct grade identified?
             my $is_grade_correct;
-            like( $stdout, "/^\Q$tool_PL\E result is '$case_grade'/ms",
+            like( $stdout, "/^CPAN::Reporter: \Q$tool_PL\E result is '$case_grade'/ms",
                 "$case->{name}: $tool_PL grade identified as '$case_grade'"
             ) and $is_grade_correct++;
             my $case_msg = $case->{"$tool\_msg"};
@@ -234,7 +234,7 @@ sub test_grade_make {
 
             # correct grade identified?
             my $is_grade_correct;
-            like( $stdout, "/^\Q$tool_label\E result is '$case_grade'/ms",
+            like( $stdout, "/^CPAN::Reporter: \Q$tool_label\E result is '$case_grade'/ms",
                 "$case->{name}: $tool_label grade identified as '$case_grade'"
             ) and $is_grade_correct++;
             my $case_msg = $case->{"$tool\_msg"};
@@ -323,7 +323,7 @@ sub test_grade_test {
             # Special case if discarding
             if ( $case->{"$tool\_grade"} eq 'discard' ) {
                 $is_grade_correct = 
-                    $stdout =~ /Test results were not valid/ms;
+                    $stdout =~ /^CPAN::Reporter: Test results were not valid/ms;
 
                 ok( $is_grade_correct,
                     "$case->{name}: '$tool_label' prerequisites not satisifed"
@@ -341,7 +341,7 @@ sub test_grade_test {
             else {
                 my $case_grade = $case->{"$tool\_grade"};
                 $is_grade_correct = 
-                    $stdout =~ /^Test result is '$case_grade'/ms;
+                    $stdout =~ /^CPAN::Reporter: Test result is '$case_grade'/ms;
                 ok( $is_grade_correct, 
                     "$case->{name}: '$tool_label' grade reported as '$case_grade'"
                 );
@@ -525,10 +525,20 @@ sub _ok_clone_dist_dir {
     my $dist_dir = File::Spec->catdir( qw/t dist /, $dist_name );
     my $work_dir = tempdir( 
         "CPAN-Reporter-testdist-XXXXXXXX", TMPDIR => 1, CLEANUP => 1
-    ) or die "Couldn't create temporary config dir: $!\n";
-    ok( dircopy($dist_dir, $work_dir),
-        "Copying $dist_name to temporary build directory"
-    );
+    ) or die "Couldn't create temporary distribution dir: $!\n";
+
+    # workaround badly broken F::C::R 0.34 on Windows
+    if ( File::Copy::Recursive->VERSION eq '0.34' && $^O eq 'MSWin32' ) {
+        ok( 0 == system("xcopy /q /e $dist_dir $work_dir"),
+            "Copying $dist_name to temporary build directory (XCOPY)"
+        ) or diag $!;
+    }
+    else {
+        ok( defined( dircopy($dist_dir, $work_dir) ),
+            "Copying $dist_name to temporary build directory"
+        ) or diag $!;
+    }
+
     return $work_dir;
 }
 
